aboutsummaryrefslogtreecommitdiffhomepage
path: root/parse_tree.h
diff options
context:
space:
mode:
authorGravatar ridiculousfish <corydoras@ridiculousfish.com>2014-02-13 10:08:04 -0800
committerGravatar ridiculousfish <corydoras@ridiculousfish.com>2014-02-13 10:10:49 -0800
commit1fbf63381782b0badead61d1576ad6a1e29fc3ea (patch)
tree778b1397a565f6cc214ae62ed6c15921d77d63b7 /parse_tree.h
parentf733dc5eae81c092f74522f4e5cc7b3d27f2b943 (diff)
Reimplement exec parsing. Instead of special-casing exec as a command,
promote it to a decoration (like 'command' or 'builtin'). This makes tab completion and syntax highlighting treat exec's first argument as a command and is otherwise a nice simplification. Fixes #1300
Diffstat (limited to 'parse_tree.h')
-rw-r--r--parse_tree.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/parse_tree.h b/parse_tree.h
index 255ab467..77b29fc8 100644
--- a/parse_tree.h
+++ b/parse_tree.h
@@ -247,9 +247,9 @@ bool parse_tree_from_string(const wcstring &str, parse_tree_flags_t flags, parse
boolean_statement = AND statement | OR statement | NOT statement
-# A decorated_statement is a command with a list of arguments_or_redirections, possibly with "builtin" or "command"
+# A decorated_statement is a command with a list of arguments_or_redirections, possibly with "builtin" or "command" or "exec"
- decorated_statement = plain_statement | COMMAND plain_statement | BUILTIN plain_statement
+ decorated_statement = plain_statement | COMMAND plain_statement | BUILTIN plain_statement | EXEC plain_statement
plain_statement = <TOK_STRING> arguments_or_redirections_list optional_background
argument_list = <empty> | argument argument_list